import java.util.Scanner;
import java.io.*;

/**
 * Scans a word at a time from a named file
 * 
 * @author Philip Howard, Joel Ross
 * @version Fall 2013
 */
public class WordScanner
{
    private Scanner input;
    private boolean isOpen;
    private String nextWord;

    /**
     * Constructor for objects of class WordScanner
     * 
     * @param fileName The name of the file to scan
     */
    public WordScanner(String fileName)
    {
        isOpen = false;
        nextWord = null;
        try
        {
            input = new Scanner(new File(fileName));
            input.useDelimiter("['-]\\W+|[^\\w'-]\\W*|['-]$"); //#j# magic regex, advice from http://stackoverflow.com/questions/13793192/java-regular-expression-split-keeping-contractions
            isOpen = true;
        }
        catch (FileNotFoundException e) 
        {
            System.out.println("ERROR: "+e);
            isOpen = false;
        }
    }

    /**
     * Returns true if there is another word in the Scanner
     * @return true if and only if this scanner has another token
     */
    public boolean hasNextWord()
    {
        if (nextWord != null) 
            return true;

        nextWord = "";
        if(isOpen)
        {
            if(input.hasNext())
            {
                nextWord = input.next();
                if(nextWord.endsWith("'s")) //if possessive
                {
                    nextWord = nextWord.substring(0,nextWord.length()-2); //strip off the 's
                }
            }
            return nextWord != null && nextWord.length() != 0;
        } 
        else 
        {
            return false;
        }
    }

    /**
     * Finds and returns the next token from the Scanner
     * @return the next token. null if there is no such token.
     */
    public String nextWord()
    {
        String returnVal;

        if (hasNextWord())
        {
            returnVal = nextWord;
            nextWord = null;
            return returnVal;
        } else {
            return null;
        }
    }
}
